import * as React from "react";
import { Component } from "react";
import { FormActions } from "bkn-ui";
import _get from "lodash.get";
import _isEmpty from "lodash.isempty";
import _last from "lodash.last";
import _set from "lodash.set";
import { FormWidget } from "../FormWidget";
import { getHandler, getWidget, handlers } from "./utils";
import { findClassificationsOfSelectedCategories } from "./utils/schema";
import Grid from "@material-ui/core/Grid";
export class Form extends Component {
    constructor() {
        super(...arguments);
        this.renderFields = (data, properties) => {
            return properties
                .filter(({ key, type, metadata }) => {
                const invalid = type === 'mixed' && !metadata.component;
                if (invalid) {
                    console.error(`Mixed component (${key}) requires component function on metadata`);
                }
                return !invalid;
            })
                .filter(property => !_get(property, "metadata.hidden"))
                .map(property => {
                const { component, mapSchemaPropertyToWidgetProps } = getWidget(property);
                const Component = component;
                const valueIsArray = property.array;
                const setHandlerFor = getHandler(property);
                const fieldValue = _get(data, property.key);
                this.tryIncludeAdditionalPropsInProperty(property);
                return (React.createElement(Component, Object.assign({ key: property.key }, mapSchemaPropertyToWidgetProps(property, fieldValue), setHandlerFor(property.key, this.handleChange))));
            });
        };
        this.tryRenderCategoriesSection = (data = {}) => {
            const { schema, categoryFieldDisabled } = this.props;
            if (_isEmpty(schema.categories)) {
                return null;
            }
            const components = [];
            const selectedCategory = (_last(data.category) || {});
            const childrenFromSelectedCategory = schema.categories.filter(c => c.parentId === selectedCategory.id);
            const rootCategories = schema.categories.filter(c => !c.parentId);
            const categorySuggestions = childrenFromSelectedCategory || rootCategories;
            const propertyType = "string";
            const inputType = "tag";
            const setHandlerFor = handlers[propertyType][inputType];
            components.push(React.createElement(FormWidget.InputTag, Object.assign({ key: "category", label: "Category", name: "category", options: mapCategoryOptions(categorySuggestions), value: mapCategoryValues(data.category, schema), disabled: categoryFieldDisabled }, setHandlerFor("category", this.handleChange))));
            const classifications = findClassificationsOfSelectedCategories(data.category, schema.categories);
            components.push(...this.renderFields(data, classifications));
            return components;
        };
        this.handleSubmit = (e) => {
            e.preventDefault();
            this.props.onSubmit(this.props.data);
        };
        this.handleChange = (changeData) => {
            const { fieldName, fieldValue } = changeData;
            const updatedData = _set(Object.assign({}, this.props.data), fieldName, fieldValue);
            this.props.onChangeFormData(updatedData);
        };
    }
    render() {
        const { children, data, hideCategoryField, loadingStateActiveOnSubmitButton, noBackButton, noJsonDebugger, noSubmitButton, schema, submitButtonDisabled, onChangeDebugObject, onClickBackButton, onClickRemoveButton } = this.props;
        return (React.createElement("form", { onSubmit: this.handleSubmit },
            children,
            schema && this.renderFields(data, schema.properties),
            !hideCategoryField && React.createElement("hr", { style: { margin: "50px 0" } }),
            schema && !hideCategoryField && this.tryRenderCategoriesSection(data),
            React.createElement(Grid, { container: true, spacing: 0 },
                React.createElement(Grid, { item: true, xs: 12 },
                    React.createElement(FormActions, { loadingStateActiveOnSubmitButton: loadingStateActiveOnSubmitButton, noBackButton: noBackButton, noJsonDebugger: noJsonDebugger, noSubmitButton: noSubmitButton, objectToDebug: data, submitButtonDisabled: submitButtonDisabled, onChangeDebugObject: onChangeDebugObject, onClickBackButton: onClickBackButton, onClickRemoveButton: onClickRemoveButton })))));
    }
    tryIncludeAdditionalPropsInProperty(property) {
        if (property.type === "geometry" &&
            property.metadata.inputType === "point") {
            property.onClickOpenMap = this.props.onClickOpenMap;
        }
        if (property.type === "file") {
            property.onClickAddImagesButton = this.props.onClickAddImagesButton;
            property.onClickRemoveImageButton = this.props.onClickRemoveImageButton;
        }
    }
}
Form.defaultProps = {
    categoryFieldDisabled: false,
    data: {},
    hideCategoryField: false,
    loadingStateActiveOnSubmitButton: false,
    noBackButton: false,
    noJsonDebugger: false,
    noSubmitButton: false,
    schema: null,
    submitButtonDisabled: false,
    onChangeDebugObject: () => null,
    onChangeFormData: () => null,
    onClickAddImagesButton: () => null,
    onClickRemoveImageButton: () => null,
    onClickBackButton: () => null,
    onClickOpenMap: () => null,
    onSubmit: () => null
};
const mapCategoryOptions = (categorySuggestions) => {
    return categorySuggestions.map(c => ({ value: c._id, label: c.name }));
};
const mapCategoryValues = (selectedCategories = [], schema) => {
    return selectedCategories
        .map(category => schema.categories.find(c => c._id === category.id))
        .map(c => ({ value: c._id, label: c.name }));
};
