import * as _get from 'lodash.get';
const defaultHandler = (fieldName, callback) => ({
    onChange: (value) => {
        callback({ fieldName, fieldValue: value });
    },
});
export const handlers = {
    geometry: {
        point: defaultHandler,
    },
    number: {
        number: defaultHandler,
    },
    options: {
        checkbox: defaultHandler,
        radio: defaultHandler,
        select: defaultHandler,
    },
    string: {
        tag: (fieldName, callback) => ({
            onChange: (value) => {
                value = value.map(v => ({ id: v.value, name: v.label }));
                callback({ fieldName, fieldValue: value });
            },
        }),
        text: defaultHandler,
        textarea: defaultHandler,
    },
};
export const getHandler = (property) => {
    const propertyType = property.type;
    const inputType = _get(property, 'metadata.inputType');
    const path = `${propertyType}.${inputType}`;
    const handler = _get(handlers, path);
    return handler || defaultHandler;
};
