import _get from "lodash.get";
import _omit from "lodash.omit";
import { FormWidget } from "./../../FormWidget";
import { SelectStrategy } from "./SelectStrategy";
const omitSomePropsFromMetadata = (metadata) => _omit(metadata, ["description", "inputType"]);
const mapCommonProps = (prop, value) => ({
    helpText: _get(prop, "metadata.description"),
    label: prop.label,
    name: prop.key,
    required: !!prop.required,
    value
});
const defaultWidgetsByType = {
    boolean: {
        component: FormWidget.InputCheck,
        mapSchemaPropertyToWidgetProps: (property, fieldValue = false) => (Object.assign({}, omitSomePropsFromMetadata(property.metadata), mapCommonProps(property, fieldValue), { checked: fieldValue, text: property.label, label: "" }))
    },
    date: {
        component: FormWidget.InputDate,
        mapSchemaPropertyToWidgetProps: (property, fieldValue = "") => (Object.assign({}, omitSomePropsFromMetadata(property.metadata), mapCommonProps(property, fieldValue)))
    },
    file: {
        component: FormWidget.InputFile,
        mapSchemaPropertyToWidgetProps: (property, fieldValue) => (Object.assign({}, omitSomePropsFromMetadata(property.metadata), mapCommonProps(property, fieldValue), { onClickAddImages: property.onClickAddImagesButton, onClickRemoveImage: property.onClickRemoveImageButton }))
    },
    geometry: {
        component: FormWidget.InputGeometryPoint,
        mapSchemaPropertyToWidgetProps: (property, fieldValue) => (Object.assign({}, omitSomePropsFromMetadata(property.metadata), mapCommonProps(property, fieldValue), { onClickOpenMap: property.onClickOpenMap }))
    },
    number: {
        component: FormWidget.InputNumber,
        mapSchemaPropertyToWidgetProps: (property, fieldValue = "") => (Object.assign({}, omitSomePropsFromMetadata(property.metadata), mapCommonProps(property, fieldValue)))
    },
    options: {
        component: SelectStrategy,
        mapSchemaPropertyToWidgetProps: (property, fieldValue) => (Object.assign({}, omitSomePropsFromMetadata(property.metadata), mapCommonProps(property, fieldValue), { multiple: property.array, options: property.options }))
    },
    string: {
        component: FormWidget.InputText,
        mapSchemaPropertyToWidgetProps: (property, fieldValue = "") => (Object.assign({}, omitSomePropsFromMetadata(property.metadata), mapCommonProps(property, fieldValue), { valueIsArray: property.array }))
    }
};
export const specificWidgets = {
    number: {
        text: {
            component: FormWidget.InputText,
            mapSchemaPropertyToWidgetProps: (property, fieldValue = "") => (Object.assign({}, omitSomePropsFromMetadata(property.metadata), mapCommonProps(property, fieldValue)))
        },
        bearing: {
            component: FormWidget.InputBearing,
            mapSchemaPropertyToWidgetProps: (property, fieldValue = "") => (Object.assign({}, omitSomePropsFromMetadata(property.metadata), mapCommonProps(property, fieldValue)))
        }
    },
    options: {
        checkbox: {
            component: FormWidget.InputCheckGroup,
            mapSchemaPropertyToWidgetProps: (property, fieldValue = []) => (Object.assign({}, omitSomePropsFromMetadata(property.metadata), mapCommonProps(property, fieldValue), { columns: _get(property, "metadata.columns", 1), options: property.options }))
        },
        radio: {
            component: FormWidget.InputRadioGroup,
            mapSchemaPropertyToWidgetProps: (property, fieldValue = []) => (Object.assign({}, omitSomePropsFromMetadata(property.metadata), mapCommonProps(property, fieldValue), { columns: _get(property, "metadata.columns", 1), options: property.options }))
        }
    },
    string: {
        textarea: {
            component: FormWidget.Textarea,
            mapSchemaPropertyToWidgetProps: (property, fieldValue = "") => (Object.assign({}, omitSomePropsFromMetadata(property.metadata), mapCommonProps(property, fieldValue)))
        }
    }
};
export const getWidget = (property) => {
    const propertyType = property.type;
    const inputType = _get(property, "metadata.inputType");
    const path = `${propertyType}.${inputType}`;
    let specificWidget = _get(specificWidgets, path);
    return propertyType !== "mixed"
        ? specificWidget || _get(defaultWidgetsByType, propertyType)
        : processMixedComponent(property);
};
const processMixedComponent = (property) => {
    const { component } = property.metadata;
    const mapSchemaPropertyToWidgetProps = () => ({});
    return {
        component,
        mapSchemaPropertyToWidgetProps
    };
};
