import * as React from 'react';
import * as classNames from 'classnames';
import _omit from 'lodash.omit';
import _isNumber from 'lodash.isnumber';
import { PureComponent } from 'react';
import Grid from '@material-ui/core/Grid';
import InputAdornment from '@material-ui/core/InputAdornment';
import FormControl from '@material-ui/core/FormControl';
import { commonDefaultProps } from '../utils';
import { InputLabel } from '../InputText/InputLabel';
import { Input } from '../InputText/Input';
export class InputBearing extends PureComponent {
    constructor(props) {
        super(props);
        this.handleChange = () => (e) => {
            const newState = Object.assign({}, this.state, { value: e.target.value });
            this.setState(newState);
            this.updatedFromInside = true;
            const { value } = newState;
            this.props.onChange(value);
        };
        this.handleFocus = (focused) => () => {
            this.setState({ focused: focused });
        };
        this.state = {
            value: this.getValue(props),
            focused: false,
        };
    }
    componentWillReceiveProps(nextProps) {
        if (!this.updatedFromInside) {
            this.setState({
                value: this.getValue(nextProps),
            });
        }
    }
    componentDidUpdate() {
        this.updatedFromInside = false;
    }
    render() {
        const { disabled, helpText, label, name, required, onClickOpenMap } = _omit(this.props, [
            'className',
            'id',
        ]);
        const { value, focused } = this.state;
        const labelId = `label-for-${name}`;
        return (React.createElement(Grid, { "aria-labelledby": labelId, container: true, spacing: 0, className: "form-group" },
            React.createElement(Grid, { item: true, xs: 12, sm: 3, className: "form-label" },
                React.createElement(InputLabel, { className: "col-form-label", required: required }, label)),
            React.createElement(Grid, { item: true, xs: 12, sm: 9 },
                React.createElement("div", null,
                    React.createElement(Grid, { container: true, spacing: 0 },
                        React.createElement(Grid, { item: true, xs: 6, sm: 4 },
                            React.createElement("div", { className: classNames('input-group', { focus: focused }) },
                                React.createElement(FormControl, null,
                                    React.createElement(Input, { disabled: disabled, name: `${name}-latitude`, id: name, type: "number", value: value, onChange: this.handleChange(), onBlur: this.handleFocus(false), onFocus: this.handleFocus(true), InputProps: {
                                            classes: {
                                                disabled: 'adornment-color',
                                            },
                                            endAdornment: React.createElement(InputAdornment, { position: "end" }, "\u00B0"),
                                        } })))),
                        !disabled && (React.createElement(Grid, { item: true, xs: 12 },
                            React.createElement("div", { className: "form-control-feedback text-muted" },
                                React.createElement("a", { href: "javascript:void(0)", className: "text-uppercase form-text", title: "Open interactive map", onClick: onClickOpenMap },
                                    React.createElement("small", null, "open map"))))))),
                helpText && React.createElement("div", { className: "form-control-feedback text-muted" }, helpText))));
    }
    getValue(props) {
        const value = props.value;
        return _isNumber(value) ? value : '';
    }
}
InputBearing.defaultProps = Object.assign({}, commonDefaultProps, {
    value: '',
    onChange: () => null,
    onClickOpenMap: () => null,
});
