import * as React from "react";
import _omit from "lodash.omit";
import _get from "lodash.get";
import _isNumber from "lodash.isnumber";
import { PureComponent } from "react";
import { commonDefaultProps } from "./../utils";
import Grid from '@material-ui/core/Grid';
import FormControl from '@material-ui/core/FormControl';
import InputAdornment from '@material-ui/core/InputAdornment';
import { InputLabel } from "../InputText/InputLabel";
import { Input } from "../InputText/Input";
export class InputGeometryPoint extends PureComponent {
    constructor(props) {
        super(props);
        this.handleChange = (field) => (e) => {
            const newState = Object.assign({}, this.state, { [field]: e.target.value });
            this.setState(newState);
            this.updatedFromInside = true;
            const { longitude, latitude } = newState;
            this.props.onChange({
                coordinates: [Number(longitude), Number(latitude)],
                type: "Point"
            });
        };
        this.handleFocus = (stateProp, focused) => () => {
            this.setState({ [stateProp]: focused });
        };
        this.state = {
            longitude: this.getCoordinateValue("longitude", props),
            latitude: this.getCoordinateValue("latitude", props),
            latitudeFocused: false,
            longitudeFocused: false
        };
    }
    componentWillReceiveProps(nextProps) {
        if (!this.updatedFromInside) {
            this.setState({
                longitude: this.getCoordinateValue("longitude", nextProps),
                latitude: this.getCoordinateValue("latitude", nextProps)
            });
        }
    }
    componentDidUpdate() {
        this.updatedFromInside = false;
    }
    render() {
        const { disabled, label, name, required, onClickOpenMap } = _omit(this.props, ["className", "id"]);
        const { latitude, longitude, } = this.state;
        const labelId = `label-for-${name}`;
        return (React.createElement(Grid, { "aria-labelledby": labelId, container: true, className: "form-group", spacing: 0 },
            React.createElement(Grid, { item: true, xs: 12, sm: 3, className: "form-label" },
                React.createElement(InputLabel, { className: "col-form-label", required: required }, label)),
            React.createElement(Grid, { item: true, xs: 12, sm: 9 },
                React.createElement("div", { className: "type-geometry-point" },
                    React.createElement(Grid, { container: true, spacing: 24 },
                        React.createElement(Grid, { item: true, xs: 6 },
                            React.createElement(FormControl, { fullWidth: true },
                                React.createElement(Input, { disabled: disabled, name: `${name}-latitude`, id: name, placeholder: "Latitude", type: "number", value: latitude, onChange: this.handleChange("latitude"), onBlur: this.handleFocus("latitudeFocused", false), onFocus: this.handleFocus("latitudeFocused", true), InputProps: {
                                        classes: {
                                            disabled: "adornment-color"
                                        },
                                        startAdornment: (React.createElement(InputAdornment, { position: "start" }, "Lat"))
                                    } }))),
                        React.createElement(Grid, { item: true, xs: 6 },
                            React.createElement(FormControl, { fullWidth: true },
                                React.createElement(Input, { disabled: disabled, name: `${name}-longitude`, id: name, placeholder: "Longitude", type: "number", value: longitude, onChange: this.handleChange("longitude"), onBlur: this.handleFocus("longitudeFocused", false), onFocus: this.handleFocus("longitudeFocused", true), InputProps: {
                                        classes: {
                                            disabled: "adornment-color"
                                        },
                                        startAdornment: (React.createElement(InputAdornment, { position: "start" }, "Lon"))
                                    } })))),
                    !disabled && (React.createElement("div", { className: "form-control-feedback text-muted" },
                        React.createElement("a", { href: "javascript:void(0)", className: "text-uppercase form-text", title: "Open interactive map", onClick: onClickOpenMap },
                            React.createElement("small", null, "open map"))))))));
    }
    getCoordinateValue(coordinateName, props) {
        const value = _get(props, `value.coordinates[${coordinateName === "longitude" ? 0 : 1}]`);
        return _isNumber(value) ? value : "";
    }
}
InputGeometryPoint.defaultProps = Object.assign({}, commonDefaultProps, {
    value: {
        coordinates: [],
        type: "Point"
    },
    onChange: () => null,
    onClickOpenMap: () => null
});
